@@ -203,20 +203,21 @@ KRecentFilesAction* ParleyActions::createRecentFilesAction(const QObject* recvr,
 
 QAction* ParleyActions::createDownloadAction(const QObject* recvr, const char* slot, KActionCollection* collection)
 {
-    QAction *pAction = KNS3::standardAction(i18n("Download New Vocabularies..."), recvr, slot, collection, "file_ghns");
-    pAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+    QAction *pAction = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("Download New Vocabularies..."), collection);
+    collection->addAction(QStringLiteral("file_ghns"), pAction);
+    QObject::connect(pAction, SIGNAL(triggered(bool)), recvr, slot);
 
-    pAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_G));
-    collection->setDefaultShortcut(pAction, QKeySequence(Qt::CTRL + Qt::Key_G));
+    pAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_G));
+    collection->setDefaultShortcut(pAction, QKeySequence(Qt::CTRL | Qt::Key_G));
     pAction->setToolTip(i18n("Downloads new vocabulary collections"));
     return pAction;
 }
 
 QAction* ParleyActions::createUploadAction(const QObject* recvr, const char* slot, KActionCollection* collection)
 {
-    QAction *pAction = KNS3::standardActionUpload(i18n("&Upload Vocabulary Document..."), recvr, slot, collection, "file_upload");
-    pAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
-
+    QAction *pAction = new QAction(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")), i18n("&Upload Vocabulary Document..."), collection);
+    collection->addAction(QStringLiteral("file_upload"), pAction);
+    QObject::connect(pAction, SIGNAL(triggered(bool)), recvr, slot);
     pAction->setToolTip(i18n("Share the current vocabulary collection with other users"));
     return pAction;
 }
